@@ -8,7 +8,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Exception;
 use Template ();
 
-our $VERSION = '1.06'; # VERSION
+our $VERSION = '1.07'; # VERSION
 
 sub register {
     my ( $self, $app, $settings ) = @_;
@@ -26,7 +26,11 @@ sub register {
 
         $template->process(
             ( ( $options->{$inline} ) ? \$options->{$inline} : $renderer->template_name($options) ),
-            { %{ $controller->stash }, ( $settings->{'settings'}{'controller'} || 'c' ) => $controller },
+            {
+                'content' => $controller->content,
+                %{ $controller->stash },
+                ( $settings->{'settings'}{'controller'} || 'c' ) => $controller,
+            },
             $output,
         ) || do {
             $app->log->error( $template->error );
@@ -79,7 +83,7 @@ Mojolicious::Plugin::ToolkitRenderer - Template Toolkit Renderer Mojolicious Plu
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Mojo-Plugin-Toolkit.svg)](https://travis-ci.org/gryphonshafer/Mojo-Plugin-Toolkit)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Mojo-Plugin-Toolkit/badge.png)](https://coveralls.io/r/gryphonshafer/Mojo-Plugin-Toolkit)
